<?php
/**
 * Cette classe me permet de gérer un fichier de langue.
 *
 * Apres avoir chargé un fichier, l'utilisation est basique.
 * Pour appeler un texte, il faut connaitre la clé corresondante et l'appel se fait grace à la méthode get().
 * Cette méthode renvoie TOUJOURS un string, si la clé n'a pas été trouvé, elle affiche un String par défaut.
 *
 * Ex :
 * $lang = new Langue($rep, $fichier);
 * ...
 * $texte = $lang->get('CLE_DE_MON_TEXTE');
 *
 *
 * Si vous avez besoin de remplacer un mot dans une phrase, vous pouvez utiliser le symbole défini par $ARG.
 * Il sera alors remplacé par le deuxième paramètre de la fonction get()
 *
 * Ex :
 * $lang = new Langue($rep, $fichier);
 * ...
 * $pseudo = "bob";
 * ...
 * $texte = $lang->get('CLE_DE_MON_TEXTE', $pseudo);
 *
 *
 * Si vous avez besoin de remplacer plusieurs mots dans une phrase, vous pouvez utiliser plusieur fois le symbole défini par $ARG.
 * Utilisez autant de paramètres que de mots à remplacer. Ces mots seront alors remplacés dans l'ordre.
 *
 * Ex :
 * $lang = new Langue($rep, $fichier);
 * ...
 * $pseudo = "bob";
 * $age = "900 ans";
 * ...
 * $texte = $lang->get('CLE_DE_MON_TEXTE', $pseudo, $age);
 *
 *
 *
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */
class Langue {

	public static $EXTENTION_LANGUE = "lang";
	private static $ARG = "%arg%";				//définition des paramètres dans le fichier .lang
	private static $ARG_REMPLACEMENT = " ";		//définition du paramètre de remplacement.
												//si dans la valeur du paramètre de remplacement, il y a $ARG, on va le remplacer pour ne pas avoir de boucle infinie.
	


	private $repertoire = "";		//répertoire qui contient les fichiers de langue
	private $nom = "";				//nom du langage (le nom du fichier sans l'extention)
	private $liste = array();		//tableau qui associe une clé à un texte traduit

	public function getNom(){return $this->nom;}
	public function setNom($nom)
	{
		//si le nom est modifié, il faut recharger la liste
		if($nom != $this->nom)
		{
			$this->nom = $nom;
			$this->charger();
		}
	}

	public function getListe(){return $this->liste;}
	public function setListe($liste){$this->liste = $liste;}

	public function getRepertoire(){return $this->repertoire;}
	public function setRepertoire($repertoire)
	{
		if($repertoire == "")
		{
			$repertoire = ".";
		}
		$this->repertoire = $repertoire;
	}



	/**
	 * lors de la construction de l'objet, on charge le fichier (le chargement se fait dans setNom())
	 * @param $repertoire	String	: chemin du répertoire contenant les fichiers lang
	 * @param $fichier		String	: nom du fichier sans l'extension (pas le chemin complet)
	 */
	public function __construct($repertoire, $fichier)
	{
		$this->setRepertoire($repertoire);
		$this->setNom($fichier);
	}


	/**
	 * méthode qui charge le tableau de langue avec le fichier
	 */
	private function charger()
	{
		$liste = array();
		$pathFichier = $this->getRepertoire() . $this->getNom() . "." . Langue::$EXTENTION_LANGUE;
		verifChemin($pathFichier);

		//si le fichier existe, je le charge, sinon, je ne charge rien et Chewbacca fera le reste.
		if(file_exists($pathFichier))
		{
			$file = fopen($pathFichier, 'r');
			while($ligne = fgets($file))
			{
				$info = explode("=",$ligne,2);
				$liste[$info[0]] = $info[1];
			}
			fclose($file);
		}
		$this->setListe($liste);
	}


	/**
	 * fonction qui renvoie la traduction pour une clé donnée
	 * @param $cle		String
	 * @param $param...	le nombre de parametres varie en fonction du nombre de terme à remplacer
	 * @return String : traduction
	 */
	public function get()
	{
		$nbArg = func_num_args();
		
		$cle = func_get_arg(0);	//le premier paramètre est toujours la clé, les suivants seront les mots à remplacer 
		$cptArg = 1;	//va servir à chercher le paramètre suivant
		$motRemplace = "";
		
		//si la clé se trouve dans le tableau, on va chercher sa valeur
		if(array_key_exists($cle, $this->getListe()))
		{
			$retour = $this->liste[$cle];

				//tant qu'on trouve un "paramètre", on le remplace et on recommence avec le mot suivant
				while (($pos = strpos($retour, Langue::$ARG)) !== false)
				{
					//on met à jour le mot de remplacement
					if($nbArg > $cptArg)
					{
						$motRemplace = func_get_arg($cptArg);
						$cptArg++;
					}
					//si $ARG se trouve dans $motRemplace, on a une boucle infinie
					$motRemplace = str_replace(Langue::$ARG, Langue::$ARG_REMPLACEMENT, $motRemplace);
					$retour = substr_replace($retour, "$motRemplace", $pos, strlen(Langue::$ARG));
				}
			return trim($retour, "\t\n\r");
		}
		else
		{
			//si la clé n'existe pas, c'est Chewbacca qui le traduit
			//bon, j'affiche quand même la clé qui pose problème
			return $cle . " : " . $this->tradChewbacca();
		}
	}


	/**
	 * traduction de Chewbacca
	 * @return String Wookie
	 */
	private function tradChewbacca()
	{
		$trad = "";
		$rand = rand(1, 10);
		for($i = 0; $i < $rand; $i++)
		{
			$trad .= "R";
		}
		$rand = rand(1, 10);
		for($i = 0; $i < $rand; $i++)
		{
			$trad .= "r";
		}
		$rand = rand(1, 10);
		for($i = 0; $i < $rand; $i++)
		{
			$trad .= "R";
		}
		$rand = rand(1, 10);
		for($i = 0; $i < $rand; $i++)
		{
			$trad .= "!";
		}
		return $trad;
	}
}
?>
